@@ -262,7 +262,6 @@ define!({
         Attribute(AttributeSelector),
         PseudoClass(PseudoClassSelector),
         PseudoElement(PseudoElementSelector),
-        At(AtSelector),
     }
 
     pub struct AttributeSelector {
@@ -336,11 +335,6 @@ define!({
         pub text: Ident,
     }
 
-    pub struct AtSelector {
-        pub span: Span,
-        pub text: Ident,
-    }
-
     pub struct Stylesheet {
         pub span: Span,
         pub rules: Vec<Rule>,
@@ -434,10 +428,15 @@ define!({
 
     pub struct DocumentRule {
         pub span: Span,
-        pub selectors: Vec<Function>,
+        pub matching_functions: Vec<DocumentRuleMatchingFunction>,
         pub block: Vec<Rule>,
     }
 
+    pub enum DocumentRuleMatchingFunction {
+        Url(Url),
+        Function(Function),
+    }
+
     pub enum KeyframesName {
         CustomIdent(CustomIdent),
         Str(Str),
